@@ -2,8 +2,8 @@
  * GSysInfo Applet
  *  - A GNOME panel applet to display various system information.
  *  Copyright (C) 1999 Jason D. Hildebrand
- *  - jdhildeb@student.math.uwaterloo.ca
- *  - http://www.student.math.uwaterloo.ca/~jdhildeb/gsysinfo
+ *  - jason@alumni.uwaterloo.ca
+ *  - http://www.opensky.ca/gsysinfo
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,12 +20,14 @@
  *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  */
 
+extern "C" {
 #include <applet-widget.h>
+}
 
 #ifndef _PROPERTIES_H
 #define _PROPERTIES_H
 
-void properties_window(AppletWidget * applet, gpointer data);
+void create_properties_window(AppletWidget * applet, gpointer data);
 void col_value_changed_cb( GtkObject * ignored, guint arg1, guint arg2,
 			   guint arg3, guint arg4, gpointer data );
 void font_value_changed_cb( GtkObject * ignored, gchar *arg1, gpointer data );
