@@ -19,12 +19,17 @@
  * provided "as is" without express or implied warranty.
  */
 
-/* $Id: sysinfo.h,v 1.1 2000/06/23 05:20:05 jdhildeb Exp $ */
+/* $Id: sysinfo.h,v 1.2 2002/01/30 17:23:09 jdhildeb Exp $ */
+
+//
+// modified in 1999, 2000, 2001 by Jason Hildebrand for use with gsysinfo 
+//
  
 #ifndef SYSINFO_INCLUDED
 #define SYSINFO_INCLUDED
 
 #define MAX_SWAPFILES 8
+#define MAX_NET_DEVS 10
 
 struct load {
 	unsigned long total;
@@ -42,9 +47,28 @@ struct meminfo {
 	unsigned long shared;
 };
 
+#define AC_ONLINE   0x01
+
+struct apminfo {
+    unsigned long has_apm;
+	unsigned long acstatus;
+	unsigned long battery_perc;	// percentage charged
+	unsigned long battery_time;	// in seconds
+};
+
+struct netinfo {
+	char iface[5];
+	unsigned long sent_bytes;
+	unsigned long received_bytes;
+	unsigned long old_sent_bytes;
+	unsigned long old_received_bytes;
+};
+
 extern void get_meminfo( int *, struct meminfo * );
-extern double get_loadavg(void);
-extern void get_load(struct load *);
+extern double get_load(void);
+extern void get_cpu(struct load *);
+void get_apm_status( struct apminfo * info );
 extern int sysinfo_init(void);
+extern int get_net_status( struct netinfo * info );
 
 #endif
